@@ -154,6 +154,10 @@ void CalcWidget::catalogSlot()
 	catalog->exec(toolBar->mapToGlobal(QPoint(catalogButton->x(),catalogButton->y()+catalogButton->height())));
 }
 
+void CalcWidget::constantsSlot()
+{
+	constants->exec(toolBar->mapToGlobal(QPoint(constantsButton->x(),constantsButton->y()+constantsButton->height())));
+}
 
 void CalcWidget::dockWindowSlot()
 {
@@ -207,5 +211,6 @@ void CalcWidget::setPref(Preferences newPref)
 	calcButtons->setPref(pref);
 	extButtons->setPref(pref);
 	textEdit->setPref(pref);
+	constants->setPref(pref);
 }
 
