@@ -75,9 +75,9 @@ int main( int argc, char **argv ) {
 	MainObject * mainObject = new MainObject;
 	mainObj=mainObject;
 
-	QFont stdFont("Helvetica");
-	stdFont.setPixelSize(14);
-	a.setFont(stdFont);
+//	QFont stdFont("Helvetica");
+//	stdFont.setPixelSize(14);
+//	a.setFont(stdFont);
 	setlocale(LC_NUMERIC,"C");	//use . for floating point values in every language
 	
 
@@ -106,6 +106,8 @@ void MainObject::closeEvent(QCloseEvent*e)
 	writeConstants();
 	writeUIState();
 	statistics->writeListsFile();
+	if(pref.currentSet.length()>0)
+		writeFunctionFile(pref.currentSet);
 	if(scripting->quitProgram())
 	{
 		e->accept();
@@ -278,6 +280,7 @@ SHOWWIN5=true\n\
 SHOWWIN6=true\n\
 SHOWWIN7=true\n\
 SHOWWIN8=false\n\
+CURRENTSET=std\n\
 F1=sinX\n\
 F2=(X+5)^2-4\n\
 F3=if(A<=10) (1-A/5)*x^2; else if(A<=20) -(x+5*(A-10)/10)^2; else -(x+5)^2-4*(A-20)/10;\n\
@@ -925,6 +928,10 @@ F20TYPE=nyquist2d\n");
 		else pref.showWindows[c]=true;
 	}
 	
+	QString currentSet=getConfigString(&confFile,"CURRENTSET");
+	if(currentSet.length()>0)
+		pref.currentSet=currentSet;
+	
 	QString*functionStrings=new QString[20];
 	
 	for(int c=0; c<20; c++)
@@ -1237,7 +1244,9 @@ void MainObject::writeConfigFile()
 	else if(pref.language == LANG_FR)
 		configuration+="fr\n";
 	else configuration+="en\n";
-
+	configuration+="\nCURRENTSET=";
+	configuration+=pref.currentSet;
+	configuration+="\n";
 
 	for(int c=0; c<8;c++)
 	{
@@ -1967,6 +1976,24 @@ void MainObject::graphTypeMenuSlot(int item)
 	pref.graphType=item;
 	getPref(pref);
 }
+
+void MainObject::graphSetMenuSlot(int item)
+{
+	writeFunctionFile(pref.currentSet);
+	pref.currentSet=graphSetMenu->text(item);
+	readFunctionFile(QString(getenv("HOME"))+"/"+QString(GRAPHSDIR)+pref.currentSet);
+	int id;
+	for(int c=0; ;c++)
+	{
+		id=graphSetMenu->idAt(c);
+		if(id==-1)
+			break;
+		else graphSetMenu->setItemChecked(id,false);
+	}
+	graphSetMenu->setItemChecked(item,true);
+
+}
+
 void MainObject::graphMenuSlot(int item)
 {
 	if(item==GRAPHIMPORT)
@@ -1987,11 +2014,103 @@ void MainObject::graphMenuSlot(int item)
 		functionDialog=new ImportDialog(pref,this,false,true);	
 		functionDialog->show();
 	}
+	else if(item==GRAPHSETMANAGE)
+	{
+		if(graphSetDialog!=NULL)
+			delete graphSetDialog;
+
+		graphSetDialog=new GraphSetDialog(pref,this);
+		graphSetDialog->show();
+	}
+	else if(item==GRAPHCREATESET)
+	{
+		bool ok;
+		QString newString=QInputDialog::getText(tr("Create New Graph Set"),tr("Insert name of new graph set:"),QLineEdit::Normal,QString::null,&ok);
+		
+		if(newString.find("/")!=-1 || newString.find("\\")!=-1)
+		{
+			ErrorBox(tr("Invalid graph set name %1").arg(newString));
+			return;
+		}
+		
+		if(ok && newString.length()>0)
+		{
+			bool exist=false;
+			QStringList dir=graphsDir->entryList(QDir::Files);
+			for(int c=0; c<(signed)dir.count(); c++)
+			{
+				if(dir[c]==newString)
+				{
+					exist=true;
+					break;
+				}
+			}
+			if(exist)
+			{
+				int ret=YesNoCancelBox(tr("%1 already exists!\n\nOverwrite it?").arg(newString));
+				if(ret!=0)
+					return;
+			}
+			 writeFunctionFile(pref.currentSet);
+			 for(int c=0; c<20; c++)
+			 {
+				 pref.functions[c]=QString();
+				 pref.functionComments[c]=QString();
+				 pref.activeFunctions[c]=false;
+				 pref.functionColors[c]=QColor(0,0,0);
+				 pref.logicFunctions[c]=false;
+				 pref.functionTypes[c]=GRAPHSTD;
+				 pref.dynamicFunctions[c]=false;
+			 }
+			 pref.currentSet=newString;
+			 writeFunctionFile(pref.currentSet);
+			 getPref(pref);
+		}
+	}
+	else if(item==GRAPHSAVECURR)
+	{
+		bool ok;
+		QString newString=QInputDialog::getText(tr("Save Current Graph Set As"),tr("Insert new name of graph set:"),QLineEdit::Normal,QString(),&ok);
+		
+		if(newString.find("/")!=-1 || newString.find("\\")!=-1)
+		{
+			ErrorBox(tr("Invalid graph set name %1").arg(newString));
+			return;
+		}
+		
+		if(ok && newString.length()>0)
+		{
+			bool exist=false;
+			QStringList dir=graphsDir->entryList(QDir::Files);
+			for(int c=0; c<(signed)dir.count(); c++)
+			{
+				if(dir[c]==newString)
+				{
+					exist=true;
+					break;
+				}
+			}
+			if(exist)
+			{
+				int ret=YesNoCancelBox(tr("%1 already exists!\n\nOverwrite it?").arg(newString));
+				if(ret!=0)
+					return;
+			}
+//			writeFunctionFile(pref.currentSet);
+			pref.currentSet=newString;
+			writeFunctionFile(pref.currentSet);
+			getPref(pref);
+		}
+	}
+}
+
+void MainObject::updateGraphSetMenuSlot()
+{
+	readGraphsDir();
 }
 
 void MainObject::tableMenuSlot(int item)
 {
-	
 	if(item==STANDARDTABLE)
 	{
 		pref.tableXStart=0;
@@ -2343,6 +2462,414 @@ void MainObject::readUIState()
 	fclose(configFile);
 }
 
+//#config color...
+//#config type...
+//#config dynamicon/off
+//#config logicon/off
+//function
+void MainObject::readFunctionFile(QString name)
+{
+	chdir(getenv("HOME"));
+	int fileLen;
+	struct stat fileStat;
+
+	if(lstat(name,&fileStat) != 0)
+	{
+		ErrorBox(tr("Unable to read file %1\n\n").arg(name));
+		return;
+	}
+	else fileLen=fileStat.st_size;
+	
+	
+	FILE*configFile = fopen(name,"r");
+	if(configFile == NULL)
+	{
+		ErrorBox(tr("Unable to read graphs file %1\n\n").arg(name));
+		return;
+	}
+	
+	int pos1=0,pos2=0,functionCount=0;
+	QString config[5],func,comment;
+	
+	char* buffer=new char[fileLen+1];
+	buffer[fileLen]=(char)0;
+	fread(buffer,fileLen,1,configFile);
+
+	QString file(buffer);
+	delete[] buffer;
+	fclose(configFile);
+	
+
+	
+	if(file.find("#config active")==-1)	//compatibility with v0.9.1 export format
+		file.replace("#config color","#config activeoff\n#config color");
+
+	
+	if(file.find("#config coordinates")==0)
+	{
+		int pos1=file.find("#config coordinates");
+		pos1+=20;
+		int pos2=file.find("\n",pos1);
+		
+		QString coordinates=file.mid(pos1,pos2-pos1);
+		file=file.right(file.length()-pos2-1);
+		QStringList coordinatesList=QStringList::split(" ",coordinates);
+		if(coordinatesList.count()>22)
+		{
+			pref.xmin=coordinatesList[0].toDouble();
+			pref.xmax=coordinatesList[1].toDouble();
+			pref.ymin=coordinatesList[2].toDouble();
+			pref.ymax=coordinatesList[3].toDouble();
+			pref.zmin=coordinatesList[4].toDouble();
+			pref.zmax=coordinatesList[5].toDouble();
+			pref.rasterSizeX=coordinatesList[6].toDouble();
+			pref.rasterSizeY=coordinatesList[7].toDouble();
+			pref.rasterSizeZ=coordinatesList[8].toDouble();
+			pref.radiusMax=coordinatesList[9].toDouble();
+			pref.angleMax=coordinatesList[10].toDouble();
+			pref.rasterSizeRadius=coordinatesList[11].toDouble();
+			pref.rasterSizeAngle=coordinatesList[12].toDouble();
+			pref.parameterStart=coordinatesList[13].toDouble();
+			pref.parameterEnd=coordinatesList[14].toDouble();
+			pref.dynamicStart=coordinatesList[15].toDouble();
+			pref.dynamicEnd=coordinatesList[16].toDouble();
+			pref.nyquistStart=coordinatesList[17].toDouble();
+			pref.nyquistEnd=coordinatesList[18].toDouble();
+			pref.tableXStart=coordinatesList[19].toDouble();
+			pref.tableXEnd=coordinatesList[20].toDouble();
+			pref.tableZStart=coordinatesList[21].toDouble();
+			pref.tableZEnd=coordinatesList[22].toDouble();
+			
+			if(pref.xmin>=pref.xmax || pref.ymin>=pref.ymax || pref.zmin>=pref.zmax)
+			{
+				pref.xmin=pref.ymin=pref.zmin=-10.0;
+				pref.xmax=pref.ymax=pref.zmax=10.0;
+			}
+			if(pref.rasterSizeX <=0 || pref.rasterSizeY<=0 || pref.rasterSizeZ<=0 || pref.rasterSizeAngle<=0 || pref.rasterSizeRadius)
+				pref.rasterSizeX=pref.rasterSizeY=pref.rasterSizeZ=pref.rasterSizeAngle=pref.rasterSizeRadius=1.0;
+			if(pref.angleMax<=0)
+				pref.angleMax=2*PI;
+			if(pref.radiusMax<=0)
+				pref.radiusMax=10.0;
+			if(pref.parameterStart>=pref.parameterEnd || pref.dynamicStart>=pref.dynamicEnd || pref.nyquistStart>=pref.nyquistEnd || pref.tableXStart>=pref.tableXEnd || pref.tableZStart>=pref.tableZEnd)
+			{
+				pref.parameterStart=pref.dynamicStart=pref.nyquistStart=pref.tableXStart=pref.tableZStart=0.0;
+				pref.parameterEnd=pref.dynamicEnd=pref.nyquistEnd=pref.tableXEnd=pref.tableZEnd=10.0;
+			}
+		}
+	}
+	if(file.find("#config steps")==0)
+	{
+		int pos1=file.find("#config steps");
+		pos1+=14;
+		int pos2=file.find("\n",pos1);
+		
+		QString coordinates=file.mid(pos1,pos2-pos1);
+		file=file.right(file.length()-pos2-1);
+		QStringList coordinatesList=QStringList::split(" ",coordinates);
+		if(coordinatesList.count()>7)
+		{
+			pref.parameterSteps=coordinatesList[0].toInt();
+			pref.dynamicSteps=coordinatesList[1].toInt();
+			pref.dynamicDelay=coordinatesList[2].toInt();
+			pref.nyquistSteps=coordinatesList[3].toInt();
+			pref.prec2dSteps=coordinatesList[4].toInt();
+			pref.prec3dSteps=coordinatesList[5].toInt();
+			pref.tableXSteps=coordinatesList[6].toInt();
+			pref.tableZSteps=coordinatesList[7].toInt();
+			
+			if(pref.parameterSteps<=0 || pref.nyquistSteps<=0 || pref.prec2dSteps<=0)
+				pref.parameterSteps=pref.nyquistSteps=pref.prec2dSteps=200;
+			if(pref.dynamicSteps<=0)
+				pref.dynamicSteps=30;
+			if(pref.tableXSteps<=0 || pref.tableZSteps <=0 || pref.dynamicDelay<=0)
+				pref.tableXSteps=pref.tableZSteps=pref.dynamicDelay=10;
+			if(pref.prec3dSteps<=0)
+				pref.prec3dSteps=50;
+		}
+	}
+	
+	if(file.find("#config flags")==0)
+	{
+		int pos1=file.find("#config flags");
+		pos1+=14;
+		int pos2=file.find("\n",pos1);
+		
+		QString coordinates=file.mid(pos1,pos2-pos1);
+		file=file.right(file.length()-pos2-1);
+		QStringList coordinatesList=QStringList::split(" ",coordinates);
+		if(coordinatesList.count()>2)
+		{
+			pref.moveUpDown=(bool)coordinatesList[0].toInt();
+			pref.show3dGrid=(bool)coordinatesList[1].toInt();
+			pref.logNyquistSteps=(bool)coordinatesList[2].toInt();
+
+		}
+	}
+	if(file.find("#config types")==0)
+	{
+		int pos1=file.find("#config types");
+		pos1+=14;
+		int pos2=file.find("\n",pos1);
+		
+		QString coordinates=file.mid(pos1,pos2-pos1);
+		file=file.right(file.length()-pos2-1);
+		QStringList coordinatesList=QStringList::split(" ",coordinates);
+		if(coordinatesList.count()>1)
+		{
+			pref.graphType=coordinatesList[0].toInt();
+			pref.tableType=coordinatesList[1].toInt();
+			
+			if(pref.graphType!=GRAPHSTD && pref.graphType !=GRAPHPOLAR && pref.graphType!=GRAPH3D)
+				pref.graphType=GRAPHSTD;
+			if(pref.tableType!=TABLENORMAL && pref.tableType !=TABLEPOLAR && pref.tableType!=TABLE3D && pref.tableType!=TABLEPARAMETER && pref.tableType !=TABLECOMPLEX && pref.tableType!=TABLEINEQUAITY)
+				pref.tableType=TABLENORMAL;
+
+		}
+	}
+
+	pos1=pos2=0;
+	while(1)
+	{
+		for(int c=0; c<5; c++)
+		{
+			pos1=file.find("#config ",pos2);
+			if(pos1==-1)
+				break;
+			pos1+=8;
+			pos2=file.find("\n",pos1);
+			if(pos2==-1)
+				break;
+			config[c]=file.mid(pos1,pos2-pos1);
+			pos2++;
+		}
+		if(pos1==-1 || pos2==-1)
+			break;
+		pos1=file.find("\n",pos2);
+		if(pos1==-1 || pos2==-1)
+			break;
+		comment=file.mid(pos2+2,pos1-pos2-2);
+		pos2=pos1+1;
+		pos1=file.find("\n",pos2);
+		if(pos1==-1 || pos2==-1)
+			break;
+		func=file.mid(pos2,pos1-pos2);
+		pos2=pos1+1;
+
+
+		pos1=config[0].find("active");
+		if(pos1==-1)
+			break;
+		config[0]=config[0].right(config[0].length()-6-pos1);
+		if(config[0]=="on")
+			pref.activeFunctions[functionCount]=true;
+		else pref.activeFunctions[functionCount]=false;
+		
+		pos1=config[1].find("color");
+		if(pos1==-1)
+			break;
+		config[1]=config[1].right(config[1].length()-pos1-5);
+		pref.functionColors[functionCount]=getColor(config[1]);
+		
+		
+		pos1=config[2].find("type");
+		if(pos1==-1)
+			break;
+		config[2]=config[2].right(config[2].length()-4-pos1);
+		
+
+		if(config[2].lower() == "nyquist3d")
+			pref.functionTypes[functionCount]=GRAPHCOMP3D;
+		else if(config[2].lower() == "parameter")
+			pref.functionTypes[functionCount]=GRAPHPARAMETER;
+		else if(config[2].lower() == "polar")
+			pref.functionTypes[functionCount]=GRAPHPOLAR;
+		else if(config[2].lower() == "3d")
+			pref.functionTypes[functionCount]=GRAPH3D;
+		else if(config[2].lower() == "iel")
+			pref.functionTypes[functionCount]=GRAPHIEL;
+		else if(config[2].lower() == "iele")
+			pref.functionTypes[functionCount]=GRAPHIELE;
+		else if(config[2].lower() == "ieg")
+			pref.functionTypes[functionCount]=GRAPHIEG;
+		else if(config[2].lower() == "iege")
+			pref.functionTypes[functionCount]=GRAPHIEGE;
+		else if(config[2].lower() == "nyquist2d")
+			pref.functionTypes[functionCount]=GRAPHCOMPLEX;
+		else pref.functionTypes[functionCount]=GRAPHSTD;
+		
+		pos1=config[3].find("dynamic");
+		if(pos1==-1)
+			break;
+		config[3]=config[3].right(config[3].length()-7-pos1);
+		if(config[3]=="on")
+			pref.dynamicFunctions[functionCount]=true;
+		else pref.dynamicFunctions[functionCount]=false;
+		
+		pos1=config[4].find("logic");
+		if(pos1==-1)
+			break;
+		config[4]=config[4].right(config[4].length()-5-pos1);
+		if(config[4]=="on")
+			pref.logicFunctions[functionCount]=true;
+		else pref.logicFunctions[functionCount]=false;
+
+		pref.functions[functionCount]=resetConfigString(func);
+		pref.functionComments[functionCount]=comment;
+		functionCount++;
+	}
+	for(int c=functionCount; c<20; c++)
+	{
+		pref.functions[c]=QString();
+		pref.functionComments[c]=QString();
+		pref.activeFunctions[c]=false;
+		pref.functionColors[c]=QColor(0,0,0);
+		pref.logicFunctions[c]=false;
+		pref.functionTypes[c]=GRAPHSTD;
+		pref.dynamicFunctions[c]=false;
+	}
+	getPref(pref);
+}
+
+void MainObject::writeFunctionFile(QString name)
+{
+	FILE*configFile;
+	chdir(getenv("HOME"));
+	configFile = fopen(GRAPHSDIR+name,"w");
+	if(configFile == NULL)
+	{
+		ErrorBox(tr("Unable to write graphs file %1\n\n").arg(GRAPHSDIR+name));
+		return;
+	}
+	QString expFile("");
+	
+	//write preferences
+	expFile+="#config coordinates ";
+	expFile+=QString::number(pref.xmin)+" ";
+	expFile+=QString::number(pref.xmax)+" ";
+	expFile+=QString::number(pref.ymin)+" ";
+	expFile+=QString::number(pref.ymax)+" ";
+	expFile+=QString::number(pref.zmin)+" ";
+	expFile+=QString::number(pref.zmax)+" ";
+	expFile+=QString::number(pref.rasterSizeX)+" ";
+	expFile+=QString::number(pref.rasterSizeY)+" ";
+	expFile+=QString::number(pref.rasterSizeZ)+" ";
+	expFile+=QString::number(pref.radiusMax)+" ";
+	expFile+=QString::number(pref.angleMax)+" ";
+	expFile+=QString::number(pref.rasterSizeRadius)+" ";
+	expFile+=QString::number(pref.rasterSizeAngle)+" ";
+	expFile+=QString::number(pref.parameterStart)+" ";
+	expFile+=QString::number(pref.parameterEnd)+" ";
+	expFile+=QString::number(pref.dynamicStart)+" ";
+	expFile+=QString::number(pref.dynamicEnd)+" ";
+	expFile+=QString::number(pref.nyquistStart)+" ";
+	expFile+=QString::number(pref.nyquistEnd)+" ";
+	expFile+=QString::number(pref.tableXStart)+" ";
+	expFile+=QString::number(pref.tableXEnd)+" ";
+	expFile+=QString::number(pref.tableZStart)+" ";
+	expFile+=QString::number(pref.tableZEnd)+"\n";
+
+	expFile+="#config steps ";
+	expFile+=QString::number(pref.parameterSteps)+" ";
+	expFile+=QString::number(pref.dynamicSteps)+" ";
+	expFile+=QString::number(pref.dynamicDelay)+" ";
+	expFile+=QString::number(pref.nyquistSteps)+" ";
+	expFile+=QString::number(pref.prec2dSteps)+" ";
+	expFile+=QString::number(pref.prec3dSteps)+" ";
+	expFile+=QString::number(pref.tableXSteps)+" ";
+	expFile+=QString::number(pref.tableZSteps)+"\n";
+
+	expFile+="#config flags ";
+	expFile+=QString::number(pref.moveUpDown)+" ";
+	expFile+=QString::number(pref.show3dGrid)+" ";
+	expFile+=QString::number(pref.logNyquistSteps)+"\n";
+	
+	expFile+="#config types ";
+	expFile+=QString::number(pref.graphType)+" ";
+	expFile+=QString::number(pref.tableType)+"\n";
+
+
+
+	for(int c=0; c<20; c++)
+	{
+		expFile+="#config active";
+		if(pref.activeFunctions[c])
+			expFile+="on\n";
+		else expFile+="off\n";
+		expFile+="#config color"+getColorName(pref.functionColors[c])+"\n";
+		expFile+="#config type";
+		switch(pref.functionTypes[c])
+		{
+			case GRAPHPOLAR:
+				expFile+="polar";break;
+			case GRAPHPARAMETER:
+				expFile+="parameter";break;
+			case GRAPH3D:
+				expFile+="3d";break;
+			case GRAPHIEL:
+				expFile+="iel";break;
+			case GRAPHIELE:
+				expFile+="iele";break;
+			case GRAPHIEG:
+				expFile+="ieg";break;
+			case GRAPHIEGE:
+				expFile+="iege";break;
+			case GRAPHCOMPLEX:
+				expFile+="nyquist2d";break;
+			case GRAPHCOMP3D:
+				expFile+="nyquist3d";break;
+			default:
+				expFile+="std";
+		}
+		expFile+="\n";
+		expFile+="#config dynamic";
+		if(pref.dynamicFunctions[c])
+			expFile+="on\n";
+		else expFile+="off\n";
+		expFile+="#config logic";
+		if(pref.logicFunctions[c])
+			expFile+="on\n";
+		else expFile+="off\n";
+		expFile+="//"+pref.functionComments[c]+"\n";
+		expFile+=cleanConfigString("",pref.functions[c])+"\n";
+		
+	}
+	fwrite(expFile.latin1(),expFile.length(),1,configFile);
+
+	fclose(configFile);
+}
+
+void MainObject::readGraphsDir()
+{
+	if(graphsDir==NULL)
+	{
+		graphsDir=new QDir(QString(getenv("HOME"))+"/"+QString(GRAPHSDIR));
+		if(!graphsDir->exists())
+		{
+			graphsDir->mkdir(QString(getenv("HOME"))+"/"+QString(GRAPHSDIR));
+			if(!graphsDir->exists())
+			{
+				ErrorBox(tr("Unable to create graphs directory %1\n\n").arg(QString(getenv("HOME"))+"/"+QString(GRAPHSDIR)));
+				return;
+			}
+		}
+	}
+	QStringList dirEntries=graphsDir->entryList(QDir::Files);
+	if(dirEntries.empty())
+	{
+		writeFunctionFile("std");
+		dirEntries=graphsDir->entryList(QDir::Files);
+		pref.currentSet="std";
+	}
+	graphSetMenu->clear();
+	
+	for(int c=0; c<dirEntries.count(); c++)
+	{
+		int id=graphSetMenu->insertItem(dirEntries[c]);
+		if(dirEntries[c]==pref.currentSet)
+			graphSetMenu->setItemChecked(id,true);
+	}
+}
 
 
 
